import React, { useMemo} from 'react'
import { Link } from 'react-router-dom'
import {useGoogleAuth} from 'hooks'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faUser } from '@fortawesome/free-solid-svg-icons'
import { Box, Heading, Flex, Spacer, Button, Image, Avatar } from "@chakra-ui/react"
import Logo from '../img/logo.png'


const Nav = () => {
    const { isSignedIn, signOut, signIn, manager } = useGoogleAuth();
    const handleAuth = () => { isSignedIn ? signOut() : signIn();}
    const authLinkText = useMemo(() => isSignedIn ? "Logout" : "Login", [isSignedIn]);
    const userIcon = isSignedIn ? 
    <Avatar name={manager.firstName + " " + manager.lastName} boxSize="40px" borderRadius="full"  src={manager.imageUrl} alt="profile"/> : null

    return (
        <Flex className="header">
            <Box className="left-nav">
                <Link to="/"><Image src={Logo} alt="project logo" height="90%" width="80%" /></Link>
            </Box>
            <Spacer />
            <Flex className="right-nav">
                <Link className="nav-link" to="/account">{userIcon}</Link>
                <Button
                    p={2}
                    size="sm"
                    color="white"
                    fontWeight="bold"
                    borderRadius="sm"
                    bgGradient="linear(to-r, teal.500,blue.500)"
                    _hover={{
                        bgGradient: "linear(to-r, blue.500, yellow.500)",
                    }}
                    ><Link to="/orders">Orders</Link></Button>
                <Button
                    p={2}
                    size="sm"
                    color="white"
                    fontWeight="bold"
                    borderRadius="sm"
                    bgGradient="linear(to-r, teal.500,blue.500)"
                    _hover={{
                        bgGradient: "linear(to-r, yellow.500, blue.500)",
                    }}
                    onClick={handleAuth}>{authLinkText}</Button>
            </Flex>
        </Flex>
    )
}

export default Nav
