import React, {useState, useEffect} from 'react'
import {OrderDetails } from 'components'
import { Order } from 'Order';
import { useAllOrders } from 'hooks'
import {
    Table,
    Thead,
    Tbody,
    Tr,
    Th,
    Input,
  } from "@chakra-ui/react"

const OrderIndexPage = () => {
    const { orders } = useAllOrders();
    const [searchInput, setSearchInput] = useState("")
    const [allOrders, setAllOrders] = useState<Order[]>([])
    const [filteredOrders, setFilteredOrders] = useState<Order[]>([])
    const [orderDetailsArr, setOrderDetailsArr] = useState<any>([])
    const orderDetailsArrCreator = (orders: Order[]) => {
        return orders.map((order: Order, idx: any) => {
            return <Tr key={idx}><OrderDetails
            date={new Date(order.orderCreatedAt).toLocaleDateString()} 
            orderNumber={order.id}
            status={order.orderStatus}
            /></Tr>
        })
    }


    useEffect(() => {
        setAllOrders(orders)
    }, [orders])

    useEffect(() => {
        if (searchInput.length !== 0) {
            setOrderDetailsArr(orderDetailsArrCreator(filteredOrders))
        } else {
            setOrderDetailsArr(orderDetailsArrCreator(allOrders))
        }
    }, [searchInput, allOrders, filteredOrders])
    
    useEffect(() => {
        const newArray: Order[] = []
            for (const ele of allOrders) {
                if (ele.id.includes(searchInput.toLowerCase())) {
                    newArray.push(ele)
                }
            }
        setFilteredOrders(newArray)
    }, [searchInput, allOrders])

    const handleChange = (e: any) => {
        console.log(e.target.value)
        setSearchInput(e.target.value)
    }

    return (
        <div className="table-div">
            <Input 
                type="text" 
                placeholder="Search by Order Number"
                focusBorderColor="telegram.400"
                value={searchInput} 
                onChange={handleChange} 
                onKeyDown={handleChange}
                >
            </Input>
            <br/>
            <div className="index-table">
                <Table variant="striped" colorScheme="messenger" size="sm">
                    <Thead>
                        <Tr className="table-header">
                            <Th fontSize="26px" color="gray">Order number</Th>
                            <Th fontSize="26px" color="gray">Order Date</Th>
                            <Th fontSize="26px" color="gray">Order Status</Th>
                        </Tr>
                    </Thead>
                    <Tbody>
                        { orderDetailsArr }
                    </Tbody>
                </Table>
            </div>
        </div>
    )
}

export default OrderIndexPage
